@@ -7,7 +7,7 @@ use Carp qw/carp croak/;
 use List::Util qw/first/;
 use Scalar::Util qw/blessed/;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 our $MODIFY = 'Modification of a read-only value attempted';
 
@@ -330,7 +330,6 @@ sub clone {
 BEGIN {
     my @conflicts = (
         attachment => [ '-content_disposition' ],
-        nph        => [ '-date', '-server' ],
         expires    => [ '-date' ],
     );
 
@@ -354,6 +353,21 @@ BEGIN {
     }
 }
 
+sub nph {
+    my $self   = shift;
+    my $header = $self->{header};
+    my $NPH    = $self->query->nph; # => $CGI::NPH
+
+    if ( @_ ) {
+        my $nph = shift;
+        croak $MODIFY if !$nph and $NPH;
+        delete @{ $header }{qw/-date -server/} if $nph;
+        return $header->{-nph} = $nph;
+    }
+
+    $header->{-nph} or $NPH;
+}
+
 sub p3p_tags {
     my $self   = shift;
     my $header = $self->{header};
@@ -378,11 +392,12 @@ sub flatten {
     my $level = defined $_[0] ? int shift : 2;
     my $query = $self->query;
     my %copy  = %{ $self->{header} };
+    my $nph   = delete $copy{-nph} || $query->nph;
 
     my @headers;
 
-    my ( $cookie, $expires, $nph, $status, $target )
-        = delete @copy{qw/-cookie -expires -nph -status -target/};
+    my ( $charset, $cookie, $expires, $status, $target, $type )
+        = delete @copy{qw/-charset -cookie -expires -status -target -type/};
 
     push @headers, 'Server', $query->server_software if $nph;
     push @headers, 'Status', $status        if $status;
@@ -407,12 +422,7 @@ sub flatten {
         push @headers, 'Content-Disposition', qq{attachment; filename="$fn"};
     }
 
-    my ( $type, $charset ) = delete @copy{qw/-type -charset/};
-
-    # not ordered
-    while ( my ($key, $value) = CORE::each %copy ) {
-        push @headers, _ucfirst($key), $value;
-    }
+    push @headers, map { _ucfirst($_), $copy{$_} } keys %copy;
 
     if ( !defined $type or $type ne q{} ) {
         $charset = $query->charset unless defined $charset;
@@ -470,8 +480,7 @@ sub NEXTKEY { $_[0]->{iterator}->() }
 
 sub _has_date {
     my $self = shift;
-    my $header = $self->{header};
-    $header->{-nph} or $header->{-cookie} or $header->{-expires};
+    $self->{header}->{-cookie} or $self->expires or $self->nph;
 }
 
 sub _ucfirst {
@@ -520,7 +529,7 @@ CGI::Header - Adapter for CGI::header() function
 
 =head1 VERSION
 
-This document refers to CGI::Header version 0.32.
+This document refers to CGI::Header version 0.34.
 
 =head1 DEPENDENCIES
 
@@ -861,7 +870,6 @@ If set to a true value, will issue the correct headers to work
 with a NPH (no-parse-header) script.
 
   $header->nph( 1 );
-  my $nph = $header->nph; # => 1
 
 =item @fields = $header->field_names
 
@@ -1081,7 +1089,7 @@ automatically, and also the header field will become read-only:
 
   if ( $header->nph ) {
       my $server = $header->get('Server');
-      # => $header->env->{SERVER_SOFTWARE}
+      # => $header->query->server_software
 
       $header->set( 'Server' => 'Apache/1.3.27 (Unix)' ); # wrong
       $header->delete( 'Server' ); # wrong
